==> msc-generator_7.1.orig.tar.xz: msc-generator-7.1/src/libgvgen/gv_lang.h <==
/* A Bison parser, made by GNU Bison 3.5.1.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Undocumented macros, especially those whose name start with YY_,
   are private implementation details.  Do not rely on them.  */

#ifndef YY_GV_GV_LANG_H_INCLUDED
# define YY_GV_GV_LANG_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int gv_debug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    TOK_EOF = 0,
    TOK_STRICT = 258,
    TOK_GRAPH = 259,
    TOK_DIGRAPH = 260,
    TOK_SUBGRAPH = 261,
    TOK_NODE = 262,
    TOK_EDGE = 263,
    TOK_EDGEOP = 264,
    TOK_EQUAL = 265,
    TOK_CLUSTER = 266,
    TOK_COLON_STRING = 267,
    TOK_COLON_QUOTED_STRING = 268,
    TOK_STRING = 269,
    TOK_QSTRING = 270,
    TOK_TILDE = 271,
    TOK_SEMICOLON = 272,
    TOK_PARAM_NAME = 273,
    TOK_OPARENTHESIS = 274,
    TOK_CPARENTHESIS = 275,
    TOK_COMMAND_DEFPROC = 276,
    TOK_COMMAND_REPLAY = 277,
    TOK_COMMAND_SET = 278,
    TOK_BYE = 279,
    TOK_IF = 280,
    TOK_THEN = 281,
    TOK_ELSE = 282,
    TOK_COMMAND_INCLUDE = 283,
    TOK_OCBRACKET = 284,
    TOK_CCBRACKET = 285,
    TOK_COMMA = 286,
    TOK_DEFDESIGN = 287,
    TOK_USEDESIGN = 288,
    TOK_DEFSTYLE = 289,
    TOK_UNRECOGNIZED_CHAR = 290
  };
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 71 "dot.yy"

    gsl::owner<char*>                                          str;
    bool                                                       boolean;
    int                                                        i;
    GraphEdgeType                                              edgetype;
    gsl::owner<CHAR_IF_CSH(Attribute)*>                        attr;
    gsl::owner<CHAR_IF_CSH(GraphStyle)*>                       attrlist;
    gsl::owner<CHAR_IF_CSH(GraphNodePort)*>                    node;
    gsl::owner<CHAR_IF_CSH(GraphNodePortList)*>                nodelist;
    gsl::owner<CHAR_IF_CSH(GraphEdgeList)*>                    edgelist;
    CHAR_IF_CSH(EdgeAttrlist)                                  edgelist_attrlist;
    gsl::owner<std::list<std::string>*>                        stringlist;
    const char*                                                input_text_ptr;
    int                                                        condition; //0:false, 1:true, 2:had_error
    ECompareOperator                                           compare_op;
    multi_segment_string                                       multi_str;
    gsl::owner<CHAR_IF_CSH(Procedure)*>                        procedure;
    CHAR_IF_CSH(const Procedure)*                              cprocedure;
    gsl::owner<CHAR_IF_CSH(ProcParamDef)*>                     procparamdef;
    gsl::owner<CHAR_IF_CSH(ProcParamDefList)*>                 procparamdeflist;
    gsl::owner<CHAR_IF_CSH(ProcParamInvocation)*>              procparaminvoc;
    gsl::owner<CHAR_IF_CSH(ProcParamInvocationList)*>          procparaminvoclist;
    gsl::owner<CHAR_IF_CSH(ProcDefParseHelper<GraphStyle>)*>   procdefhelper;

#line 119 "gv_lang.h"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif

/* Location type.  */
#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE YYLTYPE;
struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
};
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif



int gv_parse (YYMSC_RESULT_TYPE &RESULT, void *yyscanner);

#endif /* !YY_GV_GV_LANG_H_INCLUDED  */

==> msc-generator_8.1.orig.tar.xz: msc-generator-8.1/src/libgvgen/gv_lang.h <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_GV_GV_LANG_H_INCLUDED
# define YY_GV_GV_LANG_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int gv_debug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    TOK_EOF = 0,                   /* TOK_EOF  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    TOK_STRICT = 258,              /* TOK_STRICT  */
    TOK_GRAPH = 259,               /* TOK_GRAPH  */
    TOK_DIGRAPH = 260,             /* TOK_DIGRAPH  */
    TOK_SUBGRAPH = 261,            /* TOK_SUBGRAPH  */
    TOK_NODE = 262,                /* TOK_NODE  */
    TOK_EDGE = 263,                /* TOK_EDGE  */
    TOK_EDGEOP = 264,              /* TOK_EDGEOP  */
    TOK_EQUAL = 265,               /* TOK_EQUAL  */
    TOK_CLUSTER = 266,             /* TOK_CLUSTER  */
    TOK_COLON_STRING = 267,        /* TOK_COLON_STRING  */
    TOK_COLON_QUOTED_STRING = 268, /* TOK_COLON_QUOTED_STRING  */
    TOK_STRING = 269,              /* TOK_STRING  */
    TOK_QSTRING = 270,             /* TOK_QSTRING  */
    TOK_TILDE = 271,               /* TOK_TILDE  */
    TOK_SEMICOLON = 272,           /* TOK_SEMICOLON  */
    TOK_PARAM_NAME = 273,          /* TOK_PARAM_NAME  */
    TOK_OPARENTHESIS = 274,        /* TOK_OPARENTHESIS  */
    TOK_CPARENTHESIS = 275,        /* TOK_CPARENTHESIS  */
    TOK_COMMAND_DEFPROC = 276,     /* TOK_COMMAND_DEFPROC  */
    TOK_COMMAND_REPLAY = 277,      /* TOK_COMMAND_REPLAY  */
    TOK_COMMAND_SET = 278,         /* TOK_COMMAND_SET  */
    TOK_BYE = 279,                 /* TOK_BYE  */
    TOK_IF = 280,                  /* TOK_IF  */
    TOK_THEN = 281,                /* TOK_THEN  */
    TOK_ELSE = 282,                /* TOK_ELSE  */
    TOK_COMMAND_INCLUDE = 283,     /* TOK_COMMAND_INCLUDE  */
    TOK_OCBRACKET = 284,           /* TOK_OCBRACKET  */
    TOK_CCBRACKET = 285,           /* TOK_CCBRACKET  */
    TOK_COMMA = 286,               /* TOK_COMMA  */
    TOK_DEFDESIGN = 287,           /* TOK_DEFDESIGN  */
    TOK_USEDESIGN = 288,           /* TOK_USEDESIGN  */
    TOK_DEFSTYLE = 289,            /* TOK_DEFSTYLE  */
    TOK_UNRECOGNIZED_CHAR = 290    /* TOK_UNRECOGNIZED_CHAR  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 71 "dot.yy"

    gsl::owner<char*>                                          str;
    bool                                                       boolean;
    int                                                        i;
    GraphEdgeType                                              edgetype;
    gsl::owner<CHAR_IF_CSH(Attribute)*>                        attr;
    gsl::owner<CHAR_IF_CSH(GraphStyle)*>                       attrlist;
    gsl::owner<CHAR_IF_CSH(GraphNodePort)*>                    node;
    gsl::owner<CHAR_IF_CSH(GraphNodePortList)*>                nodelist;
    gsl::owner<CHAR_IF_CSH(GraphEdgeList)*>                    edgelist;
    CHAR_IF_CSH(EdgeAttrlist)                                  edgelist_attrlist;
    gsl::owner<std::list<std::string>*>                        stringlist;
    const char*                                                input_text_ptr;
    int                                                        condition; //0:false, 1:true, 2:had_error
    ECompareOperator                                           compare_op;
    multi_segment_string                                       multi_str;
    gsl::owner<CHAR_IF_CSH(Procedure)*>                        procedure;
    CHAR_IF_CSH(const Procedure)*                              cprocedure;
    gsl::owner<CHAR_IF_CSH(ProcParamDef)*>                     procparamdef;
    gsl::owner<CHAR_IF_CSH(ProcParamDefList)*>                 procparamdeflist;
    gsl::owner<CHAR_IF_CSH(ProcParamInvocation)*>              procparaminvoc;
    gsl::owner<CHAR_IF_CSH(ProcParamInvocationList)*>          procparaminvoclist;
    gsl::owner<CHAR_IF_CSH(ProcDefParseHelper<GraphStyle>)*>   procdefhelper;

#line 124 "gv_lang.h"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif

/* Location type.  */
#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
typedef struct YYLTYPE YYLTYPE;
struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
};
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif




int gv_parse (YYMSC_RESULT_TYPE &RESULT, void *yyscanner);


#endif /* !YY_GV_GV_LANG_H_INCLUDED  */
